@@ -282,7 +282,7 @@ class GAN():
         if self.generator_optimizer is None:
             raise ModelNotCompiledError("use GAN.compile() first.")
         if mlflow:
-            import mlflow
+            import mlflow  # pylint: disable=import-outside-toplevel
 
         # Retrace workaround @function signature only tensors.
         step = tf.Variable(initial_step, name="step", dtype=tf.int64)
@@ -297,13 +297,13 @@ class GAN():
         for epoch in range(epochs):
             step_float = 0
             start = time.time()
-            for image_batch in dataset:
-                generated_images, target_images = self.train_step(
-                    image_batch, batch_size, step, max_outputs, file_writer)
+            for target_images in dataset:
+                imgs = self.train_step(target_images, batch_size, step,
+                                       file_writer)
                 # TODO Workaround. summary image & gpu usage
-                with file_writer.as_default():
-                    tf.summary.image("generated", generated_images, step=step)
-                    tf.summary.image("target", target_images, step=step)
+                with file_writer.as_default():  # pylint: disable=not-context-manager
+                    tf.summary.image("target", imgs[0], step=step)
+                    tf.summary.image("fake_target", imgs[1], step=step)
 
                 file_writer.flush()
                 progbar.update(current=(step_float))
@@ -367,8 +367,7 @@ class GAN():
             self.discriminator.save(os.path.join(model_dir, "discriminator"))
 
     @tf.function
-    def train_step(self, target_images, batch_size, step, max_outputs,
-                   file_writer):
+    def train_step(self, target_images, batch_size, step, file_writer):
         """Decorated function (@tf.function) that creates a callable tensorflow
         graph from a python function.
         """
@@ -378,10 +377,9 @@ class GAN():
             # Record gradients for generator and discriminator for each seperate
             # training step.
             with tf.GradientTape() as gen_tape, tf.GradientTape() as disc_tape:
-                generated_images = self.generator(z_latent, training=True)
+                fake_target = self.generator(z_latent, training=True)
                 disc_target = self.discriminator(target_images, training=True)
-                disc_generated = self.discriminator(generated_images,
-                                                    training=True)
+                disc_generated = self.discriminator(fake_target, training=True)
 
                 gen_loss = self.generator_loss(disc_generated)
                 tf.summary.scalar("generator_loss", gen_loss, step=step)
@@ -419,8 +417,9 @@ class GAN():
             self.discriminator_optimizer.apply_gradients(
                 zip(gradients_of_discriminator,
                     self.discriminator.trainable_variables))
+            imgs = [target_images, fake_target]
             # Piece of shit workaround.
-            return generated_images, target_images
+            return imgs
 
     @staticmethod
     def discriminator_loss(real_output, fake_output):
