@@ -42,7 +42,7 @@ os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"  # FATAL
 logging.getLogger("tensorflow").setLevel(logging.FATAL)
 
 
-class YOLO(object):
+class YOLO():
     """Implements a yolo learning model.
 
         Typical usage example:
@@ -182,7 +182,7 @@ class YOLO(object):
                 Defaults to 0.25.
         """
         prediction = self.model.predict(img)
-        selected_boxes, selected_confidence, selected_classes = self.decode_yolo_output(
+        selected_boxes, selected_confidence, selected_classes = self.decode_yolo_output(  # pylint:disable=line-too-long
             prediction,
             self.anchors,
             max_number_bb=max_number_bb,
@@ -199,20 +199,20 @@ class YOLO(object):
                 item["Box"] = box
                 result.append(item)
             return result
-        else:
-            # Swap xy coordinates for bullshit tensorflow draw_bounding_boxes
-            xmin = selected_boxes[..., 0:1]
-            ymin = selected_boxes[..., 1:2]
-            xmax = selected_boxes[..., 2:3]
-            ymax = selected_boxes[..., 3:4]
 
-            boxes_yx = tf.concat([ymin, xmin, ymax, xmax], axis=-1)
+        # Swap xy coordinates for bullshit tensorflow draw_bounding_boxes
+        xmin = selected_boxes[..., 0:1]
+        ymin = selected_boxes[..., 1:2]
+        xmax = selected_boxes[..., 2:3]
+        ymax = selected_boxes[..., 3:4]
 
-            # Append batch dim.
-            boxes_yx = tf.cast(tf.expand_dims(boxes_yx, 0), dtype=tf.float32)
+        boxes_yx = tf.concat([ymin, xmin, ymax, xmax], axis=-1)
 
-            return tf.image.draw_bounding_boxes(tf.cast(img, dtype=tf.float32),
-                                                boxes_yx, self.colors)
+        # Append batch dim.
+        boxes_yx = tf.cast(tf.expand_dims(boxes_yx, 0), dtype=tf.float32)
+
+        return tf.image.draw_bounding_boxes(tf.cast(img, dtype=tf.float32),
+                                            boxes_yx, self.colors)
 
     def _append_classifier(self):
         self.feature_extractor.add(
@@ -299,7 +299,7 @@ class YOLO(object):
         if self.optimizer is None:
             raise ModelNotCompiledError("use compile() first.")
         if mlflow:
-            import mlflow
+            import mlflow  # pylint:disable=import-outside-toplevel
 
         # Retrace workaround @function signature only tensors.
         step = tf.Variable(initial_step, name="step", dtype=tf.int64)
@@ -331,7 +331,7 @@ class YOLO(object):
                 train_loss_avg.update_state(loss)
 
                 # TODO Workaround. summary image & gpu usage.
-                with file_writer.as_default():
+                with file_writer.as_default():  #pylint: disable=not-context-manager
                     tf.summary.image("label", tb_label, step=step)
                     tf.summary.image("training", tb_prediction, step=step)
 
@@ -528,7 +528,7 @@ class YOLO(object):
         Args:
             dataset ([type]): [description]
             iou_threshold (float, optional): [description]. Defaults to 0.4.
-            class_conf_threshold (float, optional): [description]. Defaults to 0.25.
+            class_conf_threshold (float, optional): [description]. Default 0.25.
             lambda_coord (float, optional): [description]. Defaults to 1.0.
             lambda_obj (float, optional): [description]. Defaults to 5.0.
             lambda_noobj (float, optional): [description]. Defaults to 1.0.
@@ -655,6 +655,7 @@ class YOLO(object):
                                    iou_threshold,
                                    class_conf_threshold,
                                    label=False):
+        del step
         tb_imgs = []
         for img in range(max_outputs):
             classes, confidence, boxes = self.decode_yolo_output(
@@ -720,7 +721,7 @@ class YOLO(object):
                   max_outputs=2,
                   step=None,
                   step_float=None,
-                  file_writer=None):
+                  file_writer=None):  # pylint:disable=too-many-statements
         groundtruth_annotations_list = []
         img_list = []
         detections_list = []
@@ -891,4 +892,4 @@ class YOLO(object):
                               val_loss_avg.result().numpy().item(),
                               step=step_float)
         print("...Done - loss {}\n".format(
-            round(val_loss_avg.result().numpy().item(), 4)))
\ No newline at end of file
+            round(val_loss_avg.result().numpy().item(), 4)))
